@@ -15,7 +15,7 @@ from aqueduct.constants.enums import (
     SerializationType,
     ServiceType,
 )
-from aqueduct.error import AqueductError
+from aqueduct.error import AqueductError, UnsupportedFeatureException
 from aqueduct.models.config import EngineConfig
 from aqueduct.models.integration import IntegrationInfo
 from pydantic import BaseModel, Extra
@@ -134,6 +134,27 @@ class LoadSpec(BaseModel):
     integration_id: uuid.UUID
     parameters: UnionLoadParams
 
+    def identifier(self) -> str:
+        if isinstance(self.parameters, RelationalDBLoadParams):
+            return self.parameters.table
+        elif isinstance(self.parameters, S3LoadParams):
+            return self.parameters.filepath
+        raise UnsupportedFeatureException(
+            "identifier() is currently unsupported for data integration type %s."
+            % self.service.value
+        )
+
+    def set_identifier(self, new_obj_identifier: str) -> None:
+        if isinstance(self.parameters, RelationalDBLoadParams):
+            self.parameters.table = new_obj_identifier
+        elif isinstance(self.parameters, S3LoadParams):
+            self.parameters.filepath = new_obj_identifier
+        else:
+            raise UnsupportedFeatureException(
+                "set_identifier() is currently unsupported for data integration type %s."
+                % self.service.value
+            )
+
 
 class EntryPoint(BaseModel):
     file: str
